@@ -1,8 +1,6 @@
 computeIC <- function(goAnno, ont) {
     ## goAnno, see godata function
-    if (!exists(".GOSemSimEnv")) .initial()
-    .GOSemSimEnv <- get(".GOSemSimEnv", envir=.GlobalEnv)
-    godata <- get("gotbl", envir=.GOSemSimEnv)        
+    godata <- ensure_gotbl_cached()
     
     goids <- unique(godata[godata$Ontology == ont, "go_id"])
     ## all GO terms appearing in an given ontology ###########
